pub struct ExecOutcome {
pub stdout: String,
pub stderr: String,
pub exit_code: Option<i32>,
pub truncated: bool,
pub timed_out: bool,
}Expand description
Result of running a single command.
Fields
stdout: Stringstderr: Stringexit_code: Option<i32>None when the process was killed (signal or timeout).
truncated: boolTrue if any stream was clipped or the process was killed by timeout.
timed_out: boolTrue if the command was terminated due to wall-clock timeout.